--[[
    RealGPSConfig

    Adds the RealGPS Configuration to all vehicles.

	@author: 		BayernGamers
	@date: 			20.05.2025
	@version:		1.0

	History:		v1.0 @20.05.2025 - initial implementation in FS25
                    ------------------------------------------------------------------------------------------------------
                    
	
	License:        Terms:
                      
    Usage:
                            Feel free to use this work as-is as long as you adhere to the following terms:
						Attribution:
							You must give appropriate credit to the original author when using this work.
						No Derivatives:
							You may not alter, transform, or build upon this work in any way.
						Usage: 
							The work may be used for personal and commercial purposes, provided it is not modified or adapted.
						Additional Clause:
							This script may not be converted, adapted, or incorporated into any other game versions or platforms except by GIANTS Software.
]]
source(Utils.getFilename("scripts/utils/LoggingUtil.lua", g_currentModDirectory))

local log = LoggingUtil.new(true, LoggingUtil.DEBUG_LEVELS.HIGH, "RealGPSConfig.lua")

RealGPSConfig = {}
RealGPSConfig.MOD_DIR = g_currentModDirectory
RealGPSConfig.MOD_NAME = g_currentModName
RealGPSConfig.BASE_PATH = "vehicle.realGPS"
RealGPSConfig.DEFAULT_VEHICLE_XML = RealGPSConfig.MOD_DIR .. "xml/defaultVehicles.xml"
RealGPSConfig.PRICE = 500

function RealGPSConfig.checkIsDefaultVehicle(xmlFile)
    local defaultVehiclesXML = XMLFile.loadIfExists("realGPSDefaultVehicles", RealGPS.DEFAULT_VEHICLE_XML, RealGPS.DEFAULT_VEHICLE_SCHEMA)

    local found = false
    if defaultVehiclesXML ~= nil then
        defaultVehiclesXML:iterate(RealGPS.DEFAULT_VEHICLE_BASE_PATH:sub(1, -4), function (index, key)
            local filename = defaultVehiclesXML:getString(key .. "#filename")
            filename = Utils.getFilename(filename)

            if xmlFile.filename == filename then
                found = true
            end
        end)
    end

    return found
end

function RealGPSConfig.isPreparedForRealGPS(xmlFile)
    local isPrepared = false

    if xmlFile ~= nil and xmlFile:hasProperty(RealGPSConfig.BASE_PATH) then
        isPrepared = true
    end

    return isPrepared
end

function RealGPSConfig.getConfigurationsFromXML(configurationManager, superFunc, xmlFile, baseKey, configs, customEnv, isMod, storeItem)
    local configurations, defaultConfigIds = superFunc(configurationManager, xmlFile, baseKey, configs, customEnv, isMod, storeItem)

    local isDefaultVehicle = RealGPSConfig.checkIsDefaultVehicle(xmlFile)
    local isPrepared = RealGPSConfig.isPreparedForRealGPS(xmlFile)

    -- Overwrite propably user defined configurations as RealGPS is not intended to support custom configs.
    if configurations ~= nil and configurations["realGPS"] ~= nil then
        configurations["realGPS"] = nil
    end

    if isDefaultVehicle or isPrepared then
        configurations = configurations == nil and {} or configurations
        defaultConfigIds = defaultConfigIds == nil and {} or defaultConfigIds
        local realGPSConfigs = {}

        local realGPSNo = VehicleConfigurationItem.new("realGPS")
        realGPSNo.name = g_i18n:getText("configuration_valueNo")
        realGPSNo.index = 1
        realGPSNo.saveId = "1"
        realGPSNo.price = 0
        realGPSNo.isYesNoOption = true
        table.insert(realGPSConfigs, realGPSNo)

        local realGPSYes = VehicleConfigurationItem.new("realGPS")
        realGPSYes.isDefault = true
        realGPSYes.name = g_i18n:getText("configuration_valueYes")
        realGPSYes.index = 2
        realGPSYes.saveId = "2"
        realGPSYes.price = RealGPSConfig.PRICE
        realGPSYes.isYesNoOption = true
        table.insert(realGPSConfigs, realGPSYes)

        defaultConfigIds.realGPS = ConfigurationUtil.getDefaultConfigIdFromItems(realGPSConfigs)
        configurations.realGPS = realGPSConfigs
    end

    return configurations, defaultConfigIds
end

ConfigurationUtil.getConfigurationsFromXML = Utils.overwrittenFunction(ConfigurationUtil.getConfigurationsFromXML, RealGPSConfig.getConfigurationsFromXML)